@@ -3,7 +3,7 @@ use warnings;
 package Glib::FindMinVersion;
 
 # ABSTRACT: Find minimum version of GLib needed to compile C source
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use Carp;
 use List::Util qw(max);
@@ -63,19 +63,29 @@ In scalar context, returns the maximum version in the list, which is the minimum
 
 =cut
 
+sub version_gt($$) {
+    my ($a, $b) = @_;
+    my ($a_major, $a_minor) = $a =~ /(\d+)\.(\d+)/g;
+    my ($b_major, $b_minor) = $b =~ /(\d+)\.(\d+)/g;
+
+    return 0 if $a_major < $b_major;
+    return 1 if $a_major > $b_major;
+    return $a_minor > $b_minor;
+}
+
 sub for_source {
-	my ($src, $current_version) = (shift, shift // '0');
+	my ($src, $current_version) = (shift, shift // '0.0');
     
     my @symbols = $src =~ / \s* (\w+) \s* \( /gx;
     return max map { $GLib_version_of{$_} // 0 } @symbols unless wantarray;
 
-    my %version_of = map { ($_, $GLib_version_of{$_} // 0) } @symbols;
+    my %version_of = map { ($_, $GLib_version_of{$_} // '0.0') } @symbols;
     my %versions;
     for (keys %version_of) {
-        push (@{ $versions{ $version_of{$_} } }, $_) if $version_of{$_} > $current_version;
+        push (@{ $versions{ $version_of{$_} } }, $_) if version_gt $version_of{$_}, $current_version;
     }
 
-    return %versions;
+    return map { ($_, $versions{$_}) } reverse sort keys %versions;
 }
 
 =item for_file($filename [, $version])
